function HidePlates:setUpInterface()
	self.frames.options = CreateFrame("Frame", "HidePlatesOptions", UIParent, BackdropTemplateMixin and "BackdropTemplate")
    tinsert(UISpecialFrames, self.frames.options:GetName())
	self.frames.options.submenus = {}
	self.frames.options.submenus[0] = "GLOBAL"
	self.frames.options.submenus[1] = "INTERRUPT"
	self.frames.options.submenus[2] = "AGGRO"
	self.frames.options.currentSubmenu = 0
	self.frames.options:SetToplevel(true)
	self.frames.options:SetFrameStrata("FULLSCREEN_DIALOG")
	self.frames.options:SetSize(365, 420)
	self.frames.options:SetPoint("CENTER")
	self.frames.options:SetBackdrop({bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
		edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Gold-Border",
		tile = true,
		tileEdge = true,
		tileSize = 32,
		edgeSize = 32,
		insets = { left = 11, right = 11, top = 11, bottom = 11 }})
	local close = self:createButton("closeButtonHidePlatesOptions", self.frames["options"], "UIPanelCloseButton", "TOPRIGHT", -10, -10)
	close:SetScript("OnClick", function()
		HidePlates.frames["options"]:Hide()
	end)
	self:createFontString(self.frames.options, "titleHidePlatesOptions", "OVERLAY", "GameFontNormal", "TOP", 10, -20, "HidePlates - Options", "Fonts\\FRIZQT__.TTF", 20, "OUTLINE, MONOCHROME")
	self.dropDown.navigation = self:createDropDown("navigationDropDownHidePlatesOptions", self.frames.options, "TOP", 10, -60, 100, "CENTER", self.frames.options.submenus[self.frames.options.currentSubmenu])
	self.dropDown.global.modifier = self:createDropDown("modifierDropDownHidePlatesOptions", self.frames.options, "TOPLEFT", 10, -120, 200, "LEFT", "Modifier: " .. self.modifiers[self.config.global.modifier])
	self.dropDown.global.toggle = self:createDropDown("toggleDropDownHidePlatesOptions", self.frames.options, "TOPLEFT", 10, -150, 200, "LEFT", "Toggle Modifier: " .. tostring(self.config.global.toggle))
	self.dropDown.global.forceHide = self:createDropDown("forceHideDropDownHidePlatesOptions", self.frames.options, "TOPLEFT", 10, -180, 200, "LEFT", "Force Hide(High CPU): " .. tostring(self.config.global.forceHide))
	self:setUpInterruptOptions()
	self:setUpAggroOptions()
	self:initializeAllDropDowns()
	for categorie in pairs(HidePlates.dropDown) do
		if categorie ~= "navigation" and categorie ~= "global" then
			for _, dropDown in pairs(HidePlates.dropDown[categorie]) do
				dropDown:Hide()
			end
		end
	end
	self.frames.options:Hide()
end

function HidePlates:setUpInterruptOptions()
	self.dropDown.interrupt.enable = self:createDropDown("interruptsEnableDropDownHidePlatesOptions", self.frames.options, "TOPLEFT", 10, -120, 200, "LEFT", "Hide not casting: " .. tostring(self.config.functions["interrupt"] ~= nil))
	self.dropDown.interrupt.notInterruptible = self:createDropDown("notInterruptibleDropDownHidePlatesOptions", self.frames.options, "TOPLEFT", 10, -150, 200, "LEFT", "Show not interruptible: " .. tostring(self.config.interrupt.notInterruptible))
end

function HidePlates:setUpAggroOptions()
	self.dropDown.aggro.enable = self:createDropDown("aggroEnableDropDownHidePlatesOptions", self.frames.options, "TOPLEFT", 10, -120, 200, "LEFT", "Hide aggro: " .. tostring(self.config.functions["aggro"] ~= nil))
end

function HidePlates:createButton(title, parent, inherit, point, posX, posY)
	local button = CreateFrame("Button", title, parent, inherit)
	button:SetPoint(point, posX, posY)
	return button
end

function HidePlates:createFontString(parent, title, layer, inherit, point, posX, posY, text, font, size, flags)
	fs = parent:CreateFontString(title, layer, inherit)
	fs:SetPoint(point, posX, posY)
	fs:SetText(text)
	fs:SetFont(font, size, flags)
	return fs
end

function HidePlates:createDropDown(title, parent, point, posX, posY, width, textPos, text)
	local dropDown = CreateFrame("FRAME", title, parent, "UIDropDownMenuTemplate")
	dropDown:SetPoint(point, posX, posY)
	UIDropDownMenu_SetWidth(dropDown, width)
	UIDropDownMenu_JustifyText(dropDown, textPos) 
	UIDropDownMenu_SetText(dropDown, text)
	
	return dropDown
end

function HidePlates:initializeDropDown(dropDown, initializer)
	UIDropDownMenu_Initialize(dropDown, initializer)
end

function HidePlates:initializeAllDropDowns()
	function self.dropDown.navigation:SetValue(newValue)
		HidePlates.frames.options.currentSubmenu = newValue
		UIDropDownMenu_SetText(HidePlates.dropDown.navigation, HidePlates.frames.options.submenus[HidePlates.frames.options.currentSubmenu])
		local selectedCategorie = string.lower(HidePlates.frames.options.submenus[HidePlates.frames.options.currentSubmenu])
		for categorie in pairs(HidePlates.dropDown) do
			if categorie ~= "navigation" and categorie ~= selectedCategorie then
				for _, dropDown in pairs(HidePlates.dropDown[categorie]) do
					dropDown:Hide()
				end
			end
		end
		local enabled
		if selectedCategorie ~= "global" then
			enabled = HidePlates.config.functions[selectedCategorie] ~= nil
		else
			enabled = true
		end
		for name, dropDown in pairs(HidePlates.dropDown[selectedCategorie]) do
			if name == "enable" then
				dropDown:Show()
			elseif enabled then
				dropDown:Show()
			end
		end
		CloseDropDownMenus()
	end
	self:initializeDropDown(self.dropDown.navigation, self.config.initializer.navigation)

	function self.dropDown.global.modifier:SetValue(newValue)
		HidePlates:updateModifier(newValue)
		UIDropDownMenu_SetText(HidePlates.dropDown.global.modifier, "Modifier: " .. HidePlates.modifiers[HidePlates.config.global.modifier])
		CloseDropDownMenus()
	end
	self:initializeDropDown(self.dropDown.global.modifier, self.config.initializer.global["modifier"])

	function self.dropDown.global.toggle:SetValue(newValue)
		HidePlates:updateToggle(newValue)
		UIDropDownMenu_SetText(HidePlates.dropDown.global.toggle, "Toggle Modifier: " .. tostring(newValue))
		CloseDropDownMenus()
	end
	self:initializeDropDown(self.dropDown.global.toggle, self.config.initializer.global["toggle"])

	function self.dropDown.global.forceHide:SetValue(newValue)
		HidePlates:updateForceHide(newValue)
		UIDropDownMenu_SetText(HidePlates.dropDown.global.forceHide, "Force Hide(High CPU): " .. tostring(newValue))
		CloseDropDownMenus()
	end
	self:initializeDropDown(self.dropDown.global.forceHide, self.config.initializer.global["forceHide"])

	function self.dropDown.interrupt.enable:SetValue(newValue)
		HidePlates:updateInterruptShow(newValue)
		UIDropDownMenu_SetText(HidePlates.dropDown.interrupt.enable, "Hide not casting: " .. tostring(newValue))
		if not newValue then
			for name, dropDown in pairs(HidePlates.dropDown.interrupt) do
				if name == "enable" then
					dropDown:Show()
				else
					dropDown:Hide()
				end
			end
		else
			for _, dropDown in pairs(HidePlates.dropDown.interrupt) do
				dropDown:Show()
			end
		end
		CloseDropDownMenus()
	end
	self:initializeDropDown(self.dropDown.interrupt.enable, self.config.initializer.interrupt["enable"])

	function self.dropDown.interrupt.notInterruptible:SetValue(newValue)
		HidePlates:updateNotInterruptible(newValue)
		UIDropDownMenu_SetText(HidePlates.dropDown.interrupt.notInterruptible, "Show not interruptible: " .. tostring(newValue))
		CloseDropDownMenus()
	end
	self:initializeDropDown(self.dropDown.interrupt.notInterruptible, self.config.initializer.interrupt["notInterruptible"])

	function self.dropDown.aggro.enable:SetValue(newValue)
		HidePlates:updateAggroShow(newValue)
		UIDropDownMenu_SetText(HidePlates.dropDown.aggro.enable, "Hide aggro: " .. tostring(newValue))
		if not newValue then
			for name, dropDown in pairs(HidePlates.dropDown.aggro) do
				if name == "enable" then
					dropDown:Show()
				else
					dropDown:Hide()
				end
			end
		else
			for _, dropDown in pairs(HidePlates.dropDown.aggro) do
				dropDown:Show()
			end
		end
		CloseDropDownMenus()
	end
	self:initializeDropDown(self.dropDown.aggro.enable, self.config.initializer.aggro["enable"])
end